@@ -15,7 +15,7 @@ class singleton(object):
 not_there = singleton('not_there')
 
 from testfixtures.comparison import (
-    Comparison, StringComparison,RoundComparison, compare, diff
+    Comparison, StringComparison, RoundComparison, compare, diff, RangeComparison
 )
 from testfixtures.tdatetime import test_datetime, test_date, test_time
 from testfixtures.logcapture import LogCapture, log_capture
